;(function(){
  var map = {
  "commitId": "23fed4f5b5cf0aaa216c2088261a14501e9c4daa",
  "branchName": "release-client-5.x",
  "buildTime": "2023-09-15 10:07:55 GMT",
  "buildVersion": "5.1.727",
  "css": [
    "@zoom/client-calendar/static/css/chunk-vendors.dc891ce4.css",
    "@zoom/client-calendar/static/css/app.c3b5793e.css"
  ],
  "js": [
    "@zoom/client-calendar/static/js/chunk-vendors.14206689.js",
    "@zoom/client-calendar/static/js/app.aa7bcce3.js"
  ],
  "key": "@zoom/client-calendar"
};
  var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
  map.css && map.css.forEach(function (cssItem) {
    var linkTag = document.createElement('link');
    var cssURL = prefix +  cssItem ;
    linkTag.href = cssURL;
    linkTag.setAttribute('rel','stylesheet');
    document.head.appendChild(linkTag);
  });
  map.js && map.js.forEach(function (jsItem) {
    var scriptTag = document.createElement("script");
    var jsURL = prefix +  jsItem;
    scriptTag.setAttribute("src", jsURL);
    document.body.appendChild(scriptTag);
  });
  window.domainFromServer= "https://dev-integration.zoomdev.us/fe-static/";
})();
